@@ -38,6 +38,7 @@
 #include <arvgcfeaturenode.h>
 #include <arvgcboolean.h>
 #include <arvgcenumeration.h>
+#include <arvgcregister.h>
 #include <arvgcstring.h>
 #include <arvstream.h>
 #include <arvdebug.h>
@@ -319,7 +320,8 @@ arv_device_get_feature_access_mode (ArvDevice *device, const char *feature)
 	g_return_val_if_fail (feature != NULL, ARV_GC_ACCESS_MODE_UNDEFINED);
 
 	node = arv_device_get_feature (device, feature);
-	return ARV_IS_GC_FEATURE_NODE (node) && arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+	g_return_val_if_fail (ARV_IS_GC_FEATURE_NODE (node), ARV_GC_ACCESS_MODE_UNDEFINED);
+	return arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
 }
 
 /**
@@ -393,6 +395,35 @@ _get_feature (ArvDevice *device, GType node_type, const char *feature, GError **
 	return node;
 }
 
+/**
+ * arv_device_get_feature_representation:
+ * @device: a #ArvDevice
+ * @feature: feature name
+ *
+ * Return: enum ArvGcRepresentation, ARV_GC_REPRESENTATION_UNDEFINED if not available.
+ *
+ * Since: 0.8.31
+ */
+
+ArvGcRepresentation
+arv_device_get_feature_representation (ArvDevice *device, const char *feature)
+{
+	ArvGcNode* node;
+
+	g_return_val_if_fail (ARV_IS_DEVICE (device), ARV_GC_REPRESENTATION_UNDEFINED);
+	g_return_val_if_fail (feature != NULL, ARV_GC_REPRESENTATION_UNDEFINED);
+
+	node = arv_device_get_feature (device, feature);
+
+	if (ARV_IS_GC_FLOAT(node)) {
+		return arv_gc_float_get_representation(ARV_GC_FLOAT(node));
+	}else if (ARV_IS_GC_INTEGER(node)){
+		return arv_gc_integer_get_representation(ARV_GC_INTEGER (node));
+	}
+
+	return ARV_GC_REPRESENTATION_UNDEFINED;
+}
+
 /**
  * arv_device_execute_command:
  * @device: a #ArvDevice
@@ -798,6 +829,55 @@ arv_device_get_float_feature_increment (ArvDevice *device, const char *feature,
 	return G_MINDOUBLE;
 }
 
+/**
+ * arv_device_set_register_feature_value:
+ * @device: a #ArvDevice
+ * @feature: feature name
+ * @value: new feature value
+ * @error: a #GError placeholder
+ *
+ * Set the register feature value.
+ *
+ * Since:
+ */
+
+void
+arv_device_set_register_feature_value (ArvDevice *device, const char *feature, guint64 length, void* value, GError **error)
+{
+	ArvGcNode *node;
+
+	node = _get_feature (device, ARV_TYPE_GC_REGISTER, feature, error);
+	if (node != NULL)
+		arv_gc_register_set (ARV_GC_REGISTER (node), value, length, error);
+}
+
+/**
+ * arv_device_dup_register_feature_value:
+ * @device: a #ArvDevice
+ * @feature: feature name
+ * @length: (out) (allow-none): register length
+ * @error: a #GError placeholder
+ *
+ * Returns: the register feature content, must be freed using [func@GLib.free].
+ *
+ * Since: 0.8.31
+ */
+
+void *
+arv_device_dup_register_feature_value (ArvDevice *device, const char *feature, guint64 *length, GError **error)
+{
+	ArvGcNode *node;
+
+        if (length != NULL)
+                *length = 0;
+
+	node = _get_feature (device, ARV_TYPE_GC_REGISTER, feature, error);
+        if (node != NULL)
+                return arv_gc_register_dup (ARV_GC_REGISTER(node), length, error);
+
+        return NULL;
+}
+
 /**
  * arv_device_dup_available_enumeration_feature_values:
  * @device: an #ArvDevice
