@@ -60,15 +60,17 @@ typedef struct {
  */
 
 static ArvGvLegacyInfos arv_gc_port_legacy_infos[] = {
-   { .vendor_selection = "Imperx",                      .model_selection = "IpxGEVCamera"},
-   { .vendor_selection = "KowaOptronics",               .model_selection = "SC130ET3"},
-   { .vendor_selection = "NIT",                         .model_selection = "Tachyon16k"},
-   { .vendor_selection = "PleoraTechnologiesInc",       .model_selection = "iPORTCLGigE"},
-   { .vendor_selection = "PleoraTechnologiesInc",       .model_selection = "NTxGigE"},
-   { .vendor_selection = "TeledyneDALSA",               .model_selection = "ICE"},
-   { .vendor_selection = "Sony",                        .model_selection = "XCG_CGSeries"},
-   { .vendor_selection = "EVK",                         .model_selection = "HELIOS"},
-   { .vendor_selection = "AT_Automation_Technology_GmbH",.model_selection = "C6_X_GigE"},
+   { .vendor_selection = "Imperx",                              .model_selection = "IpxGEVCamera"},
+   { .vendor_selection = "KowaOptronics",                       .model_selection = "SC130ET3"},
+   { .vendor_selection = "NIT",                                 .model_selection = "Tachyon16k"},
+   { .vendor_selection = "NIT",                                 .model_selection = "NSC1601GIGE"},
+   { .vendor_selection = "PleoraTechnologiesInc",               .model_selection = "iPORTCLGigE"},
+   { .vendor_selection = "PleoraTechnologiesInc",               .model_selection = "NTxGigE"},
+   { .vendor_selection = "TeledyneDALSA",                       .model_selection = "ICE"},
+   { .vendor_selection = "Sony",                                .model_selection = "XCG_CGSeries"},
+   { .vendor_selection = "Sony",                                .model_selection = "XCG_CPSeries"},
+   { .vendor_selection = "EVK",                                 .model_selection = "HELIOS"},
+   { .vendor_selection = "AT_Automation_Technology_GmbH",       .model_selection = "C6_X_GigE"},
 };
 
 typedef struct {
