@@ -1258,7 +1258,7 @@ arv_gv_device_is_controller (ArvGvDevice *gv_device)
 }
 
 static char *
-_load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **error)
+_load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, char **url, GError **error)
 {
         GError *local_error = NULL;
 	char filename[ARV_GVBS_XML_URL_SIZE];
@@ -1269,8 +1269,10 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
 	guint64 file_size;
 
 	g_return_val_if_fail (size != NULL, NULL);
+        g_return_val_if_fail (url != NULL, NULL);
 
 	*size = 0;
+        *url = NULL;
 
 	if (!arv_gv_device_read_memory (ARV_DEVICE (gv_device), address, ARV_GVBS_XML_URL_SIZE, filename, error))
 		return NULL;
@@ -1287,8 +1289,10 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
                         gsize len;
 
                         g_file_get_contents (path, &genicam, &len, NULL);
-                        if (genicam)
+                        if (genicam) {
                                 *size = len;
+                                *url = g_strdup (filename);
+                        }
                 } else if (g_ascii_strcasecmp (scheme, "local") == 0) {
                         arv_info_device ("[GvDevice::load_genicam] Xml address = 0x%" G_GINT64_MODIFIER "x - "
                                          "size = 0x%" G_GINT64_MODIFIER "x - %s", file_address, file_size, path);
@@ -1330,17 +1334,23 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
                                                                                        &tmp_buffer_size);
 
                                                         g_free (genicam);
-                                                        file_size = tmp_buffer_size;
+                                                        *size = tmp_buffer_size;
                                                         genicam = tmp_buffer;
-                                                } else
+                                                } else {
                                                         arv_warning_device ("[GvDevice::load_genicam] Invalid format");
+                                                        g_clear_pointer (&genicam, g_free);
+                                                }
                                                 arv_zip_free (zip);
+                                        } else {
+                                                *size = file_size;
                                         }
-                                        *size = file_size;
+
+                                        if (genicam != NULL)
+                                                *url = g_strdup_printf ("%s:///%s;%" G_GINT64_MODIFIER "x;%"
+                                                                        G_GINT64_MODIFIER "x", scheme, path,
+                                                                        file_address, file_size);
                                 } else {
-                                        g_free (genicam);
-                                        genicam = NULL;
-                                        *size = 0;
+                                        g_clear_pointer (&genicam, g_free);
                                 }
                         }
                 } else if (g_ascii_strcasecmp (scheme, "http")) {
@@ -1356,8 +1366,10 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
                                 data_stream = g_data_input_stream_new (G_INPUT_STREAM (stream));
                                 genicam = g_data_input_stream_read_upto (data_stream, "", 0, &len, NULL, NULL);
 
-                                if (genicam)
+                                if (genicam) {
                                         *size = len;
+                                        *url = g_strdup (filename);
+                                }
 
                                 g_object_unref (data_stream);
                                 g_object_unref (stream);
@@ -1368,51 +1380,26 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
                 }
         }
 
-	g_free (scheme);
-	g_free (path);
-
         if (local_error != NULL) {
                 arv_warning_device("Failed to load GENICAM data: %s", local_error->message);
                 g_propagate_error (error, local_error);
         }
 
+	g_free (scheme);
+	g_free (path);
+
 	return genicam;
 }
 
-static const char *
-_get_genicam_xml (ArvDevice *device, size_t *size, GError **error)
-{
-	ArvGvDevice *gv_device = ARV_GV_DEVICE (device);
-	ArvGvDevicePrivate *priv = arv_gv_device_get_instance_private (gv_device);
-	GError *local_error = NULL;
-	char *xml;
-
-	if (priv->genicam_xml != NULL) {
-		*size = priv->genicam_xml_size;
-		return priv->genicam_xml;
-	}
-
-	*size = 0;
-
-	xml = _load_genicam (gv_device, ARV_GVBS_XML_URL_0_OFFSET, size, &local_error);
-	if (xml == NULL && local_error == NULL)
-		xml = _load_genicam (gv_device, ARV_GVBS_XML_URL_1_OFFSET, size, &local_error);
-
-	if (local_error != NULL) {
-		g_propagate_error (error, local_error);
-		return NULL;
-	}
-
-	priv->genicam_xml = xml;
-	priv->genicam_xml_size = *size;
-
-	return xml;
-}
-
 static const char *
 arv_gv_device_get_genicam_xml (ArvDevice *device, size_t *size)
 {
-	return _get_genicam_xml (device, size, NULL);
+	ArvGvDevicePrivate *priv = arv_gv_device_get_instance_private (ARV_GV_DEVICE (device));
+
+        if (size != NULL)
+                *size = priv->genicam_xml_size;
+
+        return priv->genicam_xml;
 }
 
 void
@@ -1830,15 +1817,31 @@ static void
 arv_gv_device_load_genicam (ArvGvDevice *gv_device, GError **error)
 {
 	ArvGvDevicePrivate *priv = arv_gv_device_get_instance_private (gv_device);
-	const char *genicam;
+        GError *local_error = NULL;
+        char *url = NULL;
+	char *xml;
 	size_t size;
 
-	genicam = _get_genicam_xml (ARV_DEVICE (gv_device), &size, error);
-	if (genicam != NULL) {
-		priv->genicam = arv_gc_new (ARV_DEVICE (gv_device), genicam, size);
+	size = 0;
 
-                arv_gc_set_default_gv_features(priv->genicam);
+	xml = _load_genicam (gv_device, ARV_GVBS_XML_URL_0_OFFSET, &size, &url, &local_error);
+	if (xml == NULL && local_error == NULL)
+		xml = _load_genicam (gv_device, ARV_GVBS_XML_URL_1_OFFSET, &size, &url, &local_error);
+
+	if (local_error != NULL) {
+		g_propagate_error (error, local_error);
+                g_free (xml);
+                g_free (url);
+		return;
 	}
+
+	priv->genicam_xml = xml;
+	priv->genicam_xml_size = size;
+        priv->genicam = arv_gc_new (ARV_DEVICE (gv_device), xml, size);
+        arv_gc_set_default_gv_features(priv->genicam);
+        arv_dom_document_set_url (ARV_DOM_DOCUMENT(priv->genicam), url);
+
+        g_free (url);
 }
 
 /* ArvDevice implemenation */
@@ -1873,14 +1876,14 @@ arv_gv_device_create_stream (ArvDevice *device, ArvStreamCallback callback, void
 	      priv->packet_size_adjustment != ARV_GV_PACKET_SIZE_ADJUSTMENT_ON_FAILURE_ONCE) ||
 	     !priv->first_stream_created)) {
 		auto_packet_size (gv_device,
-				  priv->packet_size_adjustment == ARV_GV_PACKET_SIZE_ADJUSTMENT_ON_FAILURE ||
-				      priv->packet_size_adjustment == ARV_GV_PACKET_SIZE_ADJUSTMENT_ON_FAILURE_ONCE,
-				  &local_error);
-		if (local_error != NULL) {
-			g_propagate_error (error, local_error);
-			return NULL;
-		}
-	}
+                                  priv->packet_size_adjustment == ARV_GV_PACKET_SIZE_ADJUSTMENT_ON_FAILURE ||
+                                  priv->packet_size_adjustment == ARV_GV_PACKET_SIZE_ADJUSTMENT_ON_FAILURE_ONCE,
+                                  &local_error);
+                if (local_error != NULL) {
+                        g_propagate_error (error, local_error);
+                        return NULL;
+                }
+        }
 
 	stream = arv_gv_stream_new (gv_device, callback, user_data, destroy, error);
 	if (!ARV_IS_STREAM (stream))
