@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2019 Emmanuel Pacaud
+ * Copyright © 2009-2022 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * Author: Emmanuel Pacaud <emmanuel@gnome.org>
+ * Author: Emmanuel Pacaud <emmanuel.pacaud@free.fr>
  */
 
 #if !defined (ARV_H_INSIDE) && !defined (ARAVIS_COMPILATION)
@@ -68,7 +68,8 @@ typedef enum
 #define ARV_TYPE_GV_DEVICE             (arv_gv_device_get_type ())
 ARV_API G_DECLARE_FINAL_TYPE (ArvGvDevice, arv_gv_device, ARV, GV_DEVICE, ArvDevice)
 
-ARV_API ArvDevice *		arv_gv_device_new				(GInetAddress *interface_address, GInetAddress *device_address,
+ARV_API ArvDevice *		arv_gv_device_new				(GInetAddress *interface_address,
+                                                                                 GInetAddress *device_address,
 										 GError **error);
 
 ARV_API gboolean		arv_gv_device_take_control			(ArvGvDevice *gv_device, GError **error);
@@ -80,20 +81,36 @@ ARV_API GSocketAddress *	arv_gv_device_get_interface_address		(ArvGvDevice *devi
 ARV_API GSocketAddress *	arv_gv_device_get_device_address		(ArvGvDevice *device);
 
 ARV_API guint			arv_gv_device_get_packet_size			(ArvGvDevice *gv_device, GError **error);
-ARV_API void			arv_gv_device_set_packet_size			(ArvGvDevice *gv_device, gint packet_size, GError **error);
+ARV_API void			arv_gv_device_set_packet_size			(ArvGvDevice *gv_device, gint packet_size,
+                                                                                 GError **error);
 ARV_API void			arv_gv_device_set_packet_size_adjustment	(ArvGvDevice *gv_device,
 										 ArvGvPacketSizeAdjustment adjustment);
 ARV_API guint			arv_gv_device_auto_packet_size			(ArvGvDevice *gv_device, GError **error);
 
 ARV_API ArvGvStreamOption	arv_gv_device_get_stream_options		(ArvGvDevice *gv_device);
-ARV_API void			arv_gv_device_set_stream_options		(ArvGvDevice *gv_device, ArvGvStreamOption options);
+ARV_API void			arv_gv_device_set_stream_options		(ArvGvDevice *gv_device,
+                                                                                 ArvGvStreamOption options);
 
-ARV_API void			arv_gv_device_get_current_ip			(ArvGvDevice *gv_device, GInetAddress **ip, GInetAddressMask **mask, GInetAddress **gateway, GError **error);
-ARV_API void			arv_gv_device_get_persistent_ip			(ArvGvDevice *gv_device, GInetAddress **ip, GInetAddressMask **mask, GInetAddress **gateway, GError **error);
-ARV_API void			arv_gv_device_set_persistent_ip			(ArvGvDevice *gv_device, GInetAddress *ip, GInetAddressMask *mask, GInetAddress *gateway, GError **error);
-ARV_API void			arv_gv_device_set_persistent_ip_from_string	(ArvGvDevice *gv_device, const char *ip, const char *mask, const char *gateway, GError **error);
+ARV_API gboolean		arv_gv_device_get_current_ip			(ArvGvDevice *gv_device,
+                                                                                 GInetAddress **ip,
+                                                                                 GInetAddressMask **mask,
+                                                                                 GInetAddress **gateway, GError **error);
+ARV_API gboolean		arv_gv_device_get_persistent_ip			(ArvGvDevice *gv_device,
+                                                                                 GInetAddress **ip,
+                                                                                 GInetAddressMask **mask,
+                                                                                 GInetAddress **gateway, GError **error);
+ARV_API gboolean		arv_gv_device_set_persistent_ip			(ArvGvDevice *gv_device,
+                                                                                 GInetAddress *ip,
+                                                                                 GInetAddressMask *mask,
+                                                                                 GInetAddress *gateway, GError **error);
+ARV_API gboolean		arv_gv_device_set_persistent_ip_from_string	(ArvGvDevice *gv_device,
+                                                                                 const char *ip,
+                                                                                 const char *mask,
+                                                                                 const char *gateway, GError **error);
 ARV_API ArvGvIpConfigurationMode	arv_gv_device_get_ip_configuration_mode	(ArvGvDevice *gv_device, GError **error);
-ARV_API void			arv_gv_device_set_ip_configuration_mode		(ArvGvDevice *gv_device, ArvGvIpConfigurationMode mode, GError **error);
+ARV_API gboolean			arv_gv_device_set_ip_configuration_mode	(ArvGvDevice *gv_device,
+                                                                                 ArvGvIpConfigurationMode mode,
+                                                                                 GError **error);
 
 ARV_API gboolean		arv_gv_device_is_controller			(ArvGvDevice *gv_device);
 
